*.*.RC.txt

Header info gives:  
% src = standard source name  
% PA = kinematically determined PA (deg)  
% inc =  kinematically determined inc (deg)  
% vsys = kinematically determiend vsys in relativistic convention (km/s)  
% ra = RA from HyperLeda (J2000, deg)  
% dec = Decl from HyperLeda (J2000, deg)  
% xoff = center offset from ra (arcsec)  
% yoff = center offset from dec (arcsec)  
% Vflat = rotation velocity in flat part of rotation curve from Lelli+16 algorithm (relativistic km/s)  
% eVflat = error on Vflat (relativistic km/s)  
% Rflat = radius at which the rotation curve flattens from Lelli+16 algorithm (arcsce)  
% Rbeam = 2*bmaj used as as a proxy for the flat radius in Levy+18 (arcsec)  

Rotation curves are fit with a first order harmonic decomposition. No beam smearing correction is applied.  
Columns are:  
0: radius (arcsec)  
1: Vrot (relativistic km/s)  
2: eVrot (relativistic km/s)  
3: Vrad (relativistic km/s)  
4: eVrad (relativistic km/s)  
5: DeltaVsys (relativistic km/s)  
6: eDeltaVsys (relativistic km/s)  
